// Import msal_js
import 'package:msal_js/msal_js.dart';

/// Handle the Office single sign on
class OfficeSingleSignOn{

  /// The office client id
  final String officeClientId;

  /// The office scopes to get users info
  final List<String> scopes;

  OfficeSingleSignOn({required this.officeClientId, required this.scopes});

  /// Init the client application to retrieve the info
  PublicClientApplication init(){
    final config = Configuration()..auth = (BrowserAuthOptions()..clientId = this.officeClientId);
    return PublicClientApplication(config);
  }

  /// Login function to retrieve user info asking permissions with a popup
  Future<String?> login() async {
    PublicClientApplication publicClientApplication = this.init();
    final loginRequest = RedirectRequest()..scopes = this.scopes;
    publicClientApplication.loginRedirect(loginRequest);
    try {
      final loginRequest = PopupRequest()..scopes = this.scopes;
      final AuthenticationResult result = await publicClientApplication.loginPopup(loginRequest);
      return result.accessToken;
    } on AuthException catch (ex) {
      return null;
    }
  }


}